==> SugarCE-5.5.1.zip: SugarCE-Full-5.5.1/modules/Bugs/metadata/editviewdefs.php <==
<?php
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2010 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/
$viewdefs['Bugs']['EditView'] = array(
    'templateMeta' => array('form'=>array('hidden'=>array('<input type="hidden" name="account_id" value="{$smarty.request.account_id}">',
    											          '<input type="hidden" name="contact_id" value="{$smarty.request.contact_id}">')
    											          ),
							'maxColumns' => '2', 
                            'widths' => array(
                                            array('label' => '10', 'field' => '30'), 
                                            array('label' => '10', 'field' => '30')
                                            ),                                                                                                                                    
                                            ),
                                            
                                            
 'panels' =>array (
  'default' => 
  array (
    
    array (
      
      array (
        'name' => 'bug_number',
        'type' => 'readonly',
      ),
      'assigned_user_name',
    ),
    
    array (
      'priority',
    ),
    
    array (
      'type',
     
    ),
    
    array (
      'source',
      'status',

    ),
    
    array (
      'product_category',
      'resolution',
    ),
    
    
    array (
      'found_in_release',
      'fixed_in_release'
    ),
      
    array (
      array('name'=>'name', 'displayParams'=>array('size'=>60, 'required'=>true)),
    ),
    
    array (
      array (
	      'name' => 'description',
	      'displayParams' => 
	      array (
	        'rows' => '8',
	        'cols' => '80',
	      ),
	      'nl2br' => true,
      ),
    ),
    
    
    array (
      array (
	      'name' => 'work_log',
	      'displayParams' => 
	      array (
	        'rows' => '5',
	        'cols' => '80',
	      ),
	      'nl2br' => true,
      ),
    ),
    
  ),
                                                    
),
                        
);
?>

==> SugarCE-6.1.4.zip: SugarCE-Full-6.1.4/modules/Bugs/metadata/editviewdefs.php <==
<?php
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

$viewdefs['Bugs']['EditView'] = array(
    'templateMeta' => array('form'=>array('hidden'=>array('<input type="hidden" name="account_id" value="{$smarty.request.account_id}">',
    											          '<input type="hidden" name="contact_id" value="{$smarty.request.contact_id}">')
    											          ),
							'maxColumns' => '2', 
                            'widths' => array(
                                            array('label' => '10', 'field' => '30'), 
                                            array('label' => '10', 'field' => '30')
                                            ),                                                                                                                                    
                                            ),
                                            
                                            
 'panels' =>array (
	  'lbl_bug_information' => 
		  array (
		    
		    array (
		      array (
		        'name' => 'bug_number',
		        'type' => 'readonly',
		      ),
		    ),
		    
		    array (
		      array('name'=>'name', 'displayParams'=>array('size'=>60, 'required'=>true)),
		    ),		    
		    
		    array (
		      'priority',
		      'type',
		    ),
		    
		    array (
		      'source',
		      'status',
		
		    ),
		    
		    array (
		      'product_category',
		      'resolution',
		    ),
		    
		    
		    array (
		      'found_in_release',
		      'fixed_in_release'
		    ),
		    
		    array (
		      array (
			      'name' => 'description',
			      'nl2br' => true,
		      ),
		    ),
		    
		    
		    array (
		      array (
			      'name' => 'work_log',
			      'nl2br' => true,
		      ),
		    ),
		    
	  ),

      'LBL_PANEL_ASSIGNMENT' => 
      array (
        array (
            array (
            'name' => 'assigned_user_name',
            'label' => 'LBL_ASSIGNED_TO_NAME',
          ),
        ),
      ),  
),
                        
);
?>
